pub enum DefaultedFormOperations {
Default,
Custom(Vec<FormOperation>),
}Expand description
A default or custom set of Form operations.
A Form has a different default op field depending on its context. With this, it is possible
to specify a default operation independently from the context.
Note: an instance of this enum should not be serialized if it is a Default value.
Variants
Default
The default operation depending on the context.
Custom(Vec<FormOperation>)
A custom set of operations.
Implementations
Sourceimpl DefaultedFormOperations
impl DefaultedFormOperations
Sourcepub const fn is_default(&self) -> bool
pub const fn is_default(&self) -> bool
Returns true if the operation is a Default value.