pub enum SecurityAuthenticationLocation {
Header,
Query,
Body,
Cookie,
Uri,
}Expand description
The location of security authentication information.
Variants
Header
The parameter will be given in a header provided by the protocol, with the name of the
header provided by the value of name.
Query
The parameter will be appended to the URI as a query parameter, with the name of the query
parameter provided by name.
Body
The parameter will be provided in the body of the request payload, with the data schema
element used provided by name.
Cookie
The parameter is stored in a cookie identified by the value of name.
Uri
The parameter is embedded in the URI itself, which is encoded in the relevant interaction
using a URI template variable defined by the value of name.