pub struct ArraySchema<DS, AS, OS> {
pub items: Option<BoxedElemOrVec<DataSchema<DS, AS, OS>>>,
pub min_items: Option<u32>,
pub max_items: Option<u32>,
pub other: AS,
}Expand description
A JSON array metadata.
Fields
items: Option<BoxedElemOrVec<DataSchema<DS, AS, OS>>>The characteristics of the JSON array.
An item has a different semantic than a Vec of one item:
- a single item
Trepresents an array of element where every element must follow the schema defined byT; - a
Vecof one elementTrepresent a tuple of one single element, which must follow the schema defined byT.
In general, using a Vec of data schemas expresses a tuple of elements with a 1:1
correspondence.
min_items: Option<u32>The minimum number of items that have to be in the JSON array.
max_items: Option<u32>The maximum number of items that have to be in the JSON array.
other: ASArray schema extension.