Form

Struct Form 

pub struct Form<Other: ExtendableThing> {
    pub op: DefaultedFormOperations,
    pub href: String,
    pub content_type: Option<String>,
    pub content_coding: Option<String>,
    pub subprotocol: Option<String>,
    pub security: Option<Vec<String>>,
    pub scopes: Option<Vec<String>>,
    pub response: Option<ExpectedResponse<Other::ExpectedResponse>>,
    pub additional_responses: Option<Vec<AdditionalExpectedResponse>>,
    pub other: Other::Form,
}
The representation of an operation over a Thing.

Fields

op: DefaultedFormOperations

The semantic intention of performing the operation(s) described by the form.

href: String

Target IRI of a link or submission target of a form.

content_type: Option<String>

A content type.

It is based on a media type (e.g., text/plain) and potential parameters (e.g., charset=utf-8) for the media type (RFC2046).

content_coding: Option<String>

Content coding values indicate an encoding transformation that has been or can be applied to a representation.

Content codings are primarily used to allow a representation to be compressed or otherwise usefully transformed without losing the identity of its underlying media type and without loss of information.

Examples of content coding include “gzip”, “deflate”, etc. .

subprotocol: Option<String>

The mechanism by which an interaction will be accomplished for a given protocol when there are multiple options.

security: Option<Vec<String>>

Set of security definition names, chosen from those defined in security_definitions. These must all be satisfied for access to resources.

scopes: Option<Vec<String>>

Set of authorization scope identifiers.

The values associated with a form should be chosen from those defined in an OAuth2SecurityScheme active on that form.

response: Option<ExpectedResponse<Other::ExpectedResponse>>

The expected response from the call to the resource.

The response name contains metadata that is only valid for the primary response messages

additional_responses: Option<Vec<AdditionalExpectedResponse>>

Additional expected responses.

other: Other::Form

Form extension.